@@ -46,9 +46,11 @@
       while(_CB_num > 0){ \
         CB_d = div(_CB_num, 128); \
         _CB_num = CB_d.quot; \
-        ((signed char *)(CB_buf))[(CB_len)] = CB_d.rem; \
-        if(_CB_num > 0) \
-          ((signed char *)(CB_buf))[(CB_len)] = -(((signed char *)(CB_buf))[(CB_len)]) - 1; \
+        if(_CB_num > 0){ \
+          ((signed char *)(CB_buf))[(CB_len)] = -CB_d.rem - 1; \
+        } else { \
+          ((signed char *)(CB_buf))[(CB_len)] = CB_d.rem; \
+        } \
         (CB_len)++; \
       } \
     } \
@@ -2738,7 +2740,7 @@ CBMAP *cbxmlattrs(const char *str){
       vsiz = rp - val;
     } else {
       val = rp;
-      while(*rp > 0x20 && *rp != '"' && *rp != '\'' && *rp != '/' && *rp != '>'){
+      while(*rp > 0x20 && *rp != '"' && *rp != '\'' && *rp != '>'){
         rp++;
       }
       vsiz = rp - val;
