@@ -1308,6 +1308,13 @@ CBMAP *cbmapopenex(int bnum);
   } while(FALSE)
 
 
+/* Get the size of padding bytes for pointer alignment.
+   `hsiz' specifies the header size of the object.
+   The return value is the size of padding bytes. */
+#define CB_ALIGNPAD(CB_hsiz) \
+  (((CB_hsiz | ~-(int)sizeof(void *)) + 1) - CB_hsiz)
+
+
 /* Alias of `cbdatumopen'.
    However, no dafault data is specified. */
 #define CB_DATUMOPEN(CB_datum) \
@@ -1509,7 +1516,8 @@ CBMAP *cbmapopenex(int bnum);
     CBMAPDATUM *_CB_datum; \
     _CB_datum = (CBMAPDATUM *)((CB_kbuf) - sizeof(*_CB_datum)); \
     (CB_vsiz) = _CB_datum->vsiz; \
-    (CB_vbuf) = (char *)_CB_datum + sizeof(*_CB_datum) + _CB_datum->ksiz + 1; \
+    (CB_vbuf) = (char *)_CB_datum + sizeof(*_CB_datum) + \
+      _CB_datum->ksiz + CB_ALIGNPAD(_CB_datum->ksiz); \
   } while(FALSE)
 
 
