@@ -956,7 +956,7 @@ int runiconv(int argc, char **argv){
         free(buf);
         return 1;
       }
-      datum = cbdatumopen("", 0);
+      datum = cbdatumopen(NULL, -1);
       for(i = 0; i < nsiz; i++){
         if(norm[i] == '\r'){
           if(norm[i+1] == '\n') i++;
