@@ -672,6 +672,16 @@ int docombo(const char *name){
     }
   }
   printfflush("ok\n");
+  printfflush("Adding 64 records ... ");
+  for(i = 1; i <= 64; i++){
+    len = sprintf(buf, "%o", i);
+    if(!crput(curia, buf, len, buf, len, DP_DOVER)){
+      pdperror(name);
+      crclose(curia);
+      return 1;
+    }
+  }
+  printfflush("ok\n");
   printfflush("Syncing the database ... ");
   if(!crsync(curia)){
     pdperror(name);
@@ -679,6 +689,28 @@ int docombo(const char *name){
     return 1;
   }
   printfflush("ok\n");
+  printfflush("Retrieving records directly ... ");
+  for(i = 1; i <= 64; i++){
+    len = sprintf(buf, "%o", i);
+    if(!(vbuf = crsnaffle(name, buf, len, &vsiz))){
+      pdperror(name);
+      crclose(curia);
+      return 1;
+    }
+    if(strcmp(vbuf, buf)){
+      fprintf(stderr, "%s: %s: invalid content\n", progname, name);
+      free(vbuf);
+      crclose(curia);
+      return 1;
+    }
+    free(vbuf);
+    if(vsiz != crvsiz(curia, buf, len)){
+      fprintf(stderr, "%s: %s: invalid vsiz\n", progname, name);
+      crclose(curia);
+      return 1;
+    }
+  }
+  printfflush("ok\n");
   printfflush("Optimizing the database ... ");
   if(!croptimize(curia, -1)){
     pdperror(name);
