@@ -83,13 +83,6 @@ CURIA *cropen(const char *name, int omode, int bnum, int dnum){
       dpecodeset(DP_EMKDIR, __FILE__, __LINE__);
       return NULL;
     }
-    for(i = 0; i < dnum; i++){
-      sprintf(path, "%s%c%04d", name, MYPATHCHR, i + 1);
-      if(mkdir(path, CR_DIRMODE) == -1 && errno != EEXIST){
-        dpecodeset(DP_EMKDIR, __FILE__, __LINE__);
-        return NULL;
-      }
-    }
     sprintf(path, "%s%c%s", name, MYPATHCHR, CR_DPNAME);
     if(!(attr = dpopen(path, dpomode, CR_ATTRBNUM))) return NULL;
     if(dprnum(attr) > 0){
@@ -105,6 +98,14 @@ CURIA *cropen(const char *name, int omode, int bnum, int dnum){
         dpclose(attr);
         return NULL;
       }
+      for(i = 0; i < dnum; i++){
+        sprintf(path, "%s%c%04d", name, MYPATHCHR, i + 1);
+        if(mkdir(path, CR_DIRMODE) == -1 && errno != EEXIST){
+          dpclose(attr);
+          dpecodeset(DP_EMKDIR, __FILE__, __LINE__);
+          return NULL;
+        }
+      }
     }
   }
   if(!attr){
@@ -531,11 +532,19 @@ int crrepair(const char *name){
   DEPOT *tdepot;
   char path[CR_PATHBUFSIZ], *kbuf, *vbuf;
   struct stat sbuf;
-  int i, j, err, bnum, dnum, ksiz, vsiz;
+  int i, j, err, flags, bnum, dnum, ksiz, vsiz;
   assert(name);
   err = FALSE;
+  flags = 0;
   bnum = 0;
   dnum = 0;
+  sprintf(path, "%s%c%s", name, MYPATHCHR, CR_DPNAME);
+  if(lstat(path, &sbuf) != -1){
+    if((tdepot = dpopen(path, DP_OREADER, -1)) != NULL){
+      flags = dpgetflags(tdepot);
+      dpclose(tdepot);
+    }
+  }
   for(i = 1; i <= CR_DPMAX; i++){
     sprintf(path, "%s%c%04d%c%s", name, MYPATHCHR, i, MYPATHCHR, CR_DPNAME);
     if(lstat(path, &sbuf) != -1){
@@ -551,6 +560,7 @@ int crrepair(const char *name){
   bnum /= dnum;
   sprintf(path, "%s%s", name, CR_TMPFSUF);
   if((tcuria = cropen(path, CR_OWRITER | CR_OCREAT | CR_OTRUNC, bnum, dnum)) != NULL){
+    if(!crsetflags(tcuria, flags)) err = TRUE;
     for(i = 1; i <= CR_DPMAX; i++){
       sprintf(path, "%s%c%04d%c%s", name, MYPATHCHR, i, MYPATHCHR, CR_DPNAME);
       if(lstat(path, &sbuf) != -1){
