@@ -1991,7 +1991,7 @@ static int dprecrewrite(DEPOT *depot, int off, int rsiz, const char *kbuf, int k
   head[DP_RHIHASH] = hash;
   head[DP_RHIKSIZ] = ksiz;
   head[DP_RHIVSIZ] = vsiz;
-  head[DP_RHIPSIZ] = rsiz - sizeof(head) - ksiz - vsiz;;
+  head[DP_RHIPSIZ] = rsiz - sizeof(head) - ksiz - vsiz;
   head[DP_RHILEFT] = left;
   head[DP_RHIRIGHT] = right;
   asiz = sizeof(head) + ksiz + vsiz;
@@ -2020,7 +2020,7 @@ static int dprecrewrite(DEPOT *depot, int off, int rsiz, const char *kbuf, int k
     head[DP_RHIHASH] = hash;
     head[DP_RHIKSIZ] = ksiz;
     head[DP_RHIVSIZ] = vsiz;
-    head[DP_RHIPSIZ] = rsiz - sizeof(head) - ksiz - vsiz;;
+    head[DP_RHIPSIZ] = rsiz - sizeof(head) - ksiz - vsiz;
     head[DP_RHILEFT] = 0;
     head[DP_RHIRIGHT] = 0;
     if(!dpseekwrite(depot->fd, off, head, sizeof(head))) return FALSE;
