@@ -55,6 +55,7 @@ int runremove(int argc, char **argv);
 int runrepair(int argc, char **argv);
 int runexportdb(int argc, char **argv);
 int runimportdb(int argc, char **argv);
+int runsnaffle(int argc, char **argv);
 void pdperror(const char *name);
 void printobj(const char *obj, int size);
 void printobjhex(const char *obj, int size);
@@ -62,14 +63,16 @@ int docreate(const char *name, int bnum, int sparse);
 int doput(const char *name, const char *kbuf, int ksiz, const char *vbuf, int vsiz,
           int dmode, int align);
 int doout(const char *name, const char *kbuf, int ksiz);
-int doget(const char *name, const char *kbuf, int ksiz, int start, int max, int ox, int nb);
-int dolist(const char *name, int kb, int vb, int ox);
+int doget(const char *name, int opts, const char *kbuf, int ksiz,
+          int start, int max, int ox, int nb);
+int dolist(const char *name, int opts, int kb, int vb, int ox);
 int dooptimize(const char *name, int bnum, int align);
-int doinform(const char *name);
+int doinform(const char *name, int opts);
 int doremove(const char *name);
 int dorepair(const char *name);
 int doexportdb(const char *name, const char *file);
 int doimportdb(const char *name, const char *file, int bnum);
+int dosnaffle(const char *name, const char *kbuf, int ksiz, int ox, int nb);
 
 
 /* main routine */
@@ -103,6 +106,8 @@ int main(int argc, char **argv){
     rv = runexportdb(argc, argv);
   } else if(!strcmp(argv[1], "importdb")){
     rv = runimportdb(argc, argv);
+  } else if(!strcmp(argv[1], "snaffle")){
+    rv = runsnaffle(argc, argv);
   } else if(!strcmp(argv[1], "version") || !strcmp(argv[1], "--version")){
     printf("Powered by QDBM version %s on %s%s\n",
            dpversion, dpsysname, dpisreentrant ? " (reentrant)" : "");
@@ -124,15 +129,16 @@ void usage(void){
   fprintf(stderr, "  %s put [-kx|-ki] [-vx|-vi|-vf] [-keep|-cat] [-na] name key val\n",
           progname);
   fprintf(stderr, "  %s out [-kx|-ki] name key\n", progname);
-  fprintf(stderr, "  %s get [-kx|-ki] [-start num] [-max num] [-ox] [-n] name key\n",
+  fprintf(stderr, "  %s get [-nl] [-kx|-ki] [-start num] [-max num] [-ox] [-n] name key\n",
           progname);
-  fprintf(stderr, "  %s list [-k|-v] [-ox] name\n", progname);
+  fprintf(stderr, "  %s list [-nl] [-k|-v] [-ox] name\n", progname);
   fprintf(stderr, "  %s optimize [-bnum num] [-na] name\n", progname);
-  fprintf(stderr, "  %s inform name\n", progname);
+  fprintf(stderr, "  %s inform [-nl] name\n", progname);
   fprintf(stderr, "  %s remove name\n", progname);
   fprintf(stderr, "  %s repair name\n", progname);
   fprintf(stderr, "  %s exportdb name file\n", progname);
   fprintf(stderr, "  %s importdb [-bnum num] name file\n", progname);
+  fprintf(stderr, "  %s snaffle [-kx|-ki] [-ox] [-n] name key\n", progname);
   fprintf(stderr, "  %s version\n", progname);
   fprintf(stderr, "\n");
   exit(1);
@@ -331,8 +337,9 @@ int runout(int argc, char **argv){
 /* parse arguments of get command */
 int runget(int argc, char **argv){
   char *name, *key, *kbuf;
-  int i, kx, ki, ox, nb, start, max, ksiz, rv;
+  int i, opts, kx, ki, ox, nb, start, max, ksiz, rv;
   name = NULL;
+  opts = 0;
   kx = FALSE;
   ki = FALSE;
   ox = FALSE;
@@ -342,7 +349,9 @@ int runget(int argc, char **argv){
   key = NULL;
   for(i = 2; i < argc; i++){
     if(!name && argv[i][0] == '-'){
-      if(!strcmp(argv[i], "-kx")){
+      if(!strcmp(argv[i], "-nl")){
+        opts |= DP_ONOLCK;
+      } else if(!strcmp(argv[i], "-kx")){
         kx = TRUE;
       } else if(!strcmp(argv[i], "-ki")){
         ki = TRUE;
@@ -377,7 +386,7 @@ int runget(int argc, char **argv){
     ksiz = -1;
   }
   if(kbuf){
-    rv = doget(name, kbuf, ksiz, start, max, ox, nb);
+    rv = doget(name, opts, kbuf, ksiz, start, max, ox, nb);
   } else {
     fprintf(stderr, "%s: out of memory\n", progname);
     rv = 1;
@@ -390,14 +399,17 @@ int runget(int argc, char **argv){
 /* parse arguments of list command */
 int runlist(int argc, char **argv){
   char *name;
-  int i, kb, vb, ox, rv;
+  int i, opts, kb, vb, ox, rv;
   name = NULL;
+  opts = 0;
   kb = FALSE;
   vb = FALSE;
   ox = FALSE;
   for(i = 2; i < argc; i++){
     if(!name && argv[i][0] == '-'){
-      if(!strcmp(argv[i], "-k")){
+      if(!strcmp(argv[i], "-nl")){
+        opts |= DP_ONOLCK;
+      } else if(!strcmp(argv[i], "-k")){
         kb = TRUE;
       } else if(!strcmp(argv[i], "-v")){
         vb = TRUE;
@@ -413,7 +425,7 @@ int runlist(int argc, char **argv){
     }
   }
   if(!name) usage();
-  rv = dolist(name, kb, vb, ox);
+  rv = dolist(name, opts, kb, vb, ox);
   return rv;
 }
 
@@ -450,11 +462,16 @@ int runoptimize(int argc, char **argv){
 /* parse arguments of inform command */
 int runinform(int argc, char **argv){
   char *name;
-  int i, rv;
+  int i, opts, rv;
   name = NULL;
+  opts = 0;
   for(i = 2; i < argc; i++){
     if(!name && argv[i][0] == '-'){
-      usage();
+      if(!strcmp(argv[i], "-nl")){
+        opts |= DP_ONOLCK;
+      } else {
+        usage();
+      }
     } else if(!name){
       name = argv[i];
     } else {
@@ -462,7 +479,7 @@ int runinform(int argc, char **argv){
     }
   }
   if(!name) usage();
-  rv = doinform(name);
+  rv = doinform(name, opts);
   return rv;
 }
 
@@ -559,6 +576,59 @@ int runimportdb(int argc, char **argv){
 }
 
 
+/* parse arguments of snaffle command */
+int runsnaffle(int argc, char **argv){
+  char *name, *key, *kbuf;
+  int i, kx, ki, ox, nb, start, max, ksiz, rv;
+  name = NULL;
+  kx = FALSE;
+  ki = FALSE;
+  ox = FALSE;
+  nb = FALSE;
+  start = 0;
+  max = -1;
+  key = NULL;
+  for(i = 2; i < argc; i++){
+    if(!name && argv[i][0] == '-'){
+      if(!strcmp(argv[i], "-kx")){
+        kx = TRUE;
+      } else if(!strcmp(argv[i], "-ki")){
+        ki = TRUE;
+      } else if(!strcmp(argv[i], "-ox")){
+        ox = TRUE;
+      } else if(!strcmp(argv[i], "-n")){
+        nb = TRUE;
+      } else {
+        usage();
+      }
+    } else if(!name){
+      name = argv[i];
+    } else if(!key){
+      key = argv[i];
+    } else {
+      usage();
+    }
+  }
+  if(!name || !key || start < 0) usage();
+  if(kx){
+    kbuf = hextoobj(key, &ksiz);
+  } else if(ki){
+    kbuf = dectoiobj(key, &ksiz);
+  } else {
+    kbuf = cbmemdup(key, -1);
+    ksiz = -1;
+  }
+  if(kbuf){
+    rv = dosnaffle(name, kbuf, ksiz, ox, nb);
+  } else {
+    fprintf(stderr, "%s: out of memory\n", progname);
+    rv = 1;
+  }
+  free(kbuf);
+  return rv;
+}
+
+
 /* print an error message */
 void pdperror(const char *name){
   fprintf(stderr, "%s: %s: %s\n", progname, name, dperrmsg(dpecode));
@@ -647,11 +717,12 @@ int doout(const char *name, const char *kbuf, int ksiz){
 
 
 /* perform get command */
-int doget(const char *name, const char *kbuf, int ksiz, int start, int max, int ox, int nb){
+int doget(const char *name, int opts, const char *kbuf, int ksiz,
+          int start, int max, int ox, int nb){
   DEPOT *depot;
   char *vbuf;
   int vsiz;
-  if(!(depot = dpopen(name, DP_OREADER, -1))){
+  if(!(depot = dpopen(name, DP_OREADER | opts, -1))){
     pdperror(name);
     return 1;
   }
@@ -676,11 +747,11 @@ int doget(const char *name, const char *kbuf, int ksiz, int start, int max, int
 
 
 /* perform list command */
-int dolist(const char *name, int kb, int vb, int ox){
+int dolist(const char *name, int opts, int kb, int vb, int ox){
   DEPOT *depot;
   char *kbuf, *vbuf;
   int ksiz, vsiz;
-  if(!(depot = dpopen(name, DP_OREADER, -1))){
+  if(!(depot = dpopen(name, DP_OREADER | opts, -1))){
     pdperror(name);
     return 1;
   }
@@ -738,10 +809,10 @@ int dooptimize(const char *name, int bnum, int align){
 
 
 /* perform inform command */
-int doinform(const char *name){
+int doinform(const char *name, int opts){
   DEPOT *depot;
   char *tmp;
-  if(!(depot = dpopen(name, DP_OREADER, -1))){
+  if(!(depot = dpopen(name, DP_OREADER | opts, -1))){
     pdperror(name);
     return 1;
   }
@@ -822,5 +893,24 @@ int doimportdb(const char *name, const char *file, int bnum){
 }
 
 
+/* perform snaffle command */
+int dosnaffle(const char *name, const char *kbuf, int ksiz, int ox, int nb){
+  char *vbuf;
+  int vsiz;
+  if(!(vbuf = dpsnaffle(name, kbuf, ksiz, &vsiz))){
+    pdperror(name);
+    return 1;
+  }
+  if(ox){
+    printobjhex(vbuf, vsiz);
+  } else {
+    printobj(vbuf, vsiz);
+  }
+  free(vbuf);
+  if(!nb) putchar('\n');
+  return 0;
+}
+
+
 
 /* END OF FILE */
