@@ -635,6 +635,16 @@ int docombo(const char *name){
     }
   }
   printfflush("ok\n");
+  printfflush("Adding 64 records ... ");
+  for(i = 1; i <= 1000; i++){
+    len = sprintf(buf, "%o", i);
+    if(!dpput(depot, buf, len, buf, len, DP_DOVER)){
+      pdperror(name);
+      dpclose(depot);
+      return 1;
+    }
+  }
+  printfflush("ok\n");
   printfflush("Syncing the database ... ");
   if(!dpsync(depot)){
     pdperror(name);
@@ -642,6 +652,28 @@ int docombo(const char *name){
     return 1;
   }
   printfflush("ok\n");
+  printfflush("Retrieving records directly ... ");
+  for(i = 1; i <= 64; i++){
+    len = sprintf(buf, "%o", i);
+    if(!(vbuf = dpsnaffle(name, buf, len, &vsiz))){
+      pdperror(name);
+      dpclose(depot);
+      return 1;
+    }
+    if(strcmp(vbuf, buf)){
+      fprintf(stderr, "%s: %s: invalid content\n", progname, name);
+      free(vbuf);
+      dpclose(depot);
+      return 1;
+    }
+    free(vbuf);
+    if(vsiz != dpvsiz(depot, buf, len)){
+      fprintf(stderr, "%s: %s: invalid vsiz\n", progname, name);
+      dpclose(depot);
+      return 1;
+    }
+  }
+  printfflush("ok\n");
   printfflush("Optimizing the database ... ");
   if(!dpoptimize(depot, -1)){
     pdperror(name);
