@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Implementation of Hovel
- *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2006 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -14,6 +14,8 @@
  *************************************************************************************************/
 
 
+#define QDBM_INTERNAL  1
+
 #include "hovel.h"
 #include "myconf.h"
 
@@ -205,7 +207,7 @@ GDBM_FILE gdbm_open2(char *name, int read_write, int mode, int bnum, int dnum, i
     gdbm_errno = GDBM_ILLEGAL_DATA;
     return NULL;
   }
-  if(stat(name, &sbuf) != -1){
+  if(lstat(name, &sbuf) != -1){
     if(S_ISDIR(sbuf.st_mode)){
       if(dnum < 1) dnum = 1;
     } else {
