@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * The GDBM-compatible API of QDBM
- *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2006 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -29,13 +29,20 @@ extern "C" {
 #include <sys/stat.h>
 
 
+#if defined(_MSC_VER) && !defined(QDBM_INTERNAL) && !defined(QDBM_STATIC)
+#define MYEXTERN extern __declspec(dllimport)
+#else
+#define MYEXTERN extern
+#endif
+
+
 
 /*************************************************************************************************
  * API
  *************************************************************************************************/
 
 
-typedef enum {                           /* type of enumeration for error codes */
+enum {                                   /* enumeration for error codes */
   GDBM_NO_ERROR,                         /* no error */
   GDBM_MALLOC_ERROR,                     /* malloc error */
   GDBM_BLOCK_SIZE_ERROR,                 /* block size error */
@@ -57,12 +64,14 @@ typedef enum {                           /* type of enumeration for error codes
   GDBM_ILLEGAL_DATA,                     /* illegal data */
   GDBM_OPT_ALREADY_SET,                  /* option already set */
   GDBM_OPT_ILLEGAL                       /* option illegal */
-} gdbm_error;
+};
+
+typedef int gdbm_error;                  /* type of error codes */
 
 typedef struct {                         /* type of structure for a database handle */
   DEPOT *depot;                          /* internal database handle of Depot */
   CURIA *curia;                          /* internal database handle of Curia */
-  int syncmode;                          /* wheter syncronous mode or not */
+  int syncmode;                          /* whether to be besyncronous mode */
 } GDBM;
 
 typedef GDBM *GDBM_FILE;                 /* type of pointer to a database handle */
@@ -99,7 +108,7 @@ enum {                                   /* enumeration for options */
 
 
 /* String containing the version information. */
-extern char *gdbm_version;
+MYEXTERN char *gdbm_version;
 
 
 /* Last happened error code. */
@@ -257,6 +266,8 @@ int *gdbm_errnoptr(void);
 
 
 
+#undef MYEXTERN
+
 #if defined(__cplusplus)                 /* export for C++ */
 }
 #endif
