@@ -197,7 +197,8 @@ int odput(ODEUM *odeum, ODDOC *doc, int wmax, int over){
     cblistpush(tlist, ctmp, wsiz);
   }
   tmp = cblistdump(tlist, &tsiz);
-  cbmapputvbuf(map, OD_NWORDSEXPR, sizeof(OD_NWORDSEXPR), tmp, tsiz);
+  cbmapput(map, OD_NWORDSEXPR, sizeof(OD_NWORDSEXPR), tmp, tsiz, TRUE);
+  free(tmp);
   cblistclose(tlist);
   tlist = cblistopen();
   for(i = 0; i < wmax; i++){
@@ -209,7 +210,8 @@ int odput(ODEUM *odeum, ODDOC *doc, int wmax, int over){
     }
   }
   tmp = cblistdump(tlist, &tsiz);
-  cbmapputvbuf(map, OD_AWORDSEXPR, sizeof(OD_AWORDSEXPR), tmp, tsiz);
+  cbmapput(map, OD_AWORDSEXPR, sizeof(OD_AWORDSEXPR), tmp, tsiz, TRUE);
+  free(tmp);
   cblistclose(tlist);
   tmp = cbmapdump(map, &tsiz);
   cbmapclose(map);
