@@ -89,7 +89,7 @@ void otcb(const char *fname, ODEUM *odeum, const char *msg);
 void pdperror(const char *name);
 void printferror(const char *format, ...);
 void printfinfo(const char *format, ...);
-const char *datestr(int t);
+const char *datestr(time_t t);
 int proclist(const char *name, const char *lfile, int wmax,
              const CBLIST *tsuflist, const CBLIST *hsuflist);
 int procdir(const char *name, const char *dir, int wmax,
@@ -325,12 +325,10 @@ void printfinfo(const char *format, ...){
 
 
 /* get static string of the date */
-const char *datestr(int t){
+const char *datestr(time_t t){
   static char buf[32];
   struct tm *stp;
-  time_t tt;
-  tt = (time_t)t;
-  if(!(stp = localtime(&tt))) return "0000/00/00 00:00:00";
+  if(!(stp = localtime(&t))) return "0000/00/00 00:00:00";
   sprintf(buf, "%04d/%02d/%02d %02d:%02d:%02d",
           stp->tm_year + 1900, stp->tm_mon + 1, stp->tm_mday,
           stp->tm_hour, stp->tm_min, stp->tm_sec);
@@ -493,7 +491,8 @@ int indexfile(ODEUM *odeum, VILLA *mtdb, const char *name, const char *file, int
   static int cnt = 0;
   char *vbuf, *buf, *uri;
   const char *title;
-  int size, mtime, hot, vsiz, wnum, bnum;
+  int size, hot, vsiz, wnum, bnum;
+  time_t mtime;
   ODDOC *doc;
   if(!cbfilestat(file, NULL, &size, &mtime)){
     printferror("%s: file does not exist", file);
