@@ -369,7 +369,7 @@ int runsearch(int argc, char **argv){
     }
   }
   if(!name) usage();
-  text = cbdatumopen("", 0);
+  text = cbdatumopen(NULL, -1);
   for(i = 0; i < wnum; i++){
     if(i > 0) cbdatumcat(text, " ", 1);
     cbdatumcat(text, srchwords[i], -1);
