@@ -87,6 +87,7 @@ class Villa
   # Method: Called implicitly by the constructor.
   #
   def initialize(name, omode = OREADER, cmode = CMPLEX)
+    @silent = false
     MyMutex.synchronize() do
       @index = mod_open(name, omode, cmode)
       @name = name
@@ -121,7 +122,7 @@ class Villa
   ##
   # bool = villa.close()
   # Method: Close the database handle.
-  # The return value is always `true'.
+  # The return value is always true.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs.
   # Because the region of a closed handle is released, it becomes impossible to use the handle.
   # Updating a database is assured to be written when the handle is closed.  If a writer opens
@@ -138,6 +139,19 @@ class Villa
     end
   end
   ##
+  # villa.silent = bool
+  # Method: Set the flag whether to repress frequent exceptions.
+  # The return value is the assigned value.
+  #
+  def silent=(value)
+    @silent = value ? true : false
+    mod_setsilent(@index, silent ? 1 : 0)
+    @silent
+  end
+  def silent
+    @silent
+  end
+  ##
   # bool = villa.put(key, val, dmode)
   # Method: Store a record.
   # `key' specifies a key.  Although it must be an instance of String, binary data is okey.
@@ -149,7 +163,8 @@ class Villa
   # specified value is added as the last one, `Villa::DDUPR', which means duplication of keys is
   # allowed and the specified value is added as the first one.  If it is omitted, `Villa::DOVER'
   # is specified.
-  # The return value is always `true'.
+  # The return value is always true.  However, if the silent flag is true and replace is
+  # cancelled, false is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or replace
   # is cancelled.
   # The cursor becomes unavailable due to updating database.
@@ -167,7 +182,7 @@ class Villa
   #
   alias store put
   ##
-  # str = (villa[key] = val)
+  # villa[key] = val
   # Method: An alias of `put'.
   #
   alias []= put
@@ -175,7 +190,8 @@ class Villa
   # bool = villa.out(key)
   # Method: Delete a record.
   # `key' specifies a key.  Although it must be an instance of String, binary data is okey.
-  # The return value is always `true'.
+  # The return value is always true.  However, if the silent flag is true and no record
+  # corresponds, false is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or no record
   # corresponds.
   # When the key of duplicated records is specified, the value of the first record of the same
@@ -195,7 +211,7 @@ class Villa
   ##
   # bool = villa.clear()
   # Method: Delete all records.
-  # The return value is always `true'.
+  # The return value is always true.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs.
   #
   def clear
@@ -214,7 +230,8 @@ class Villa
   # str = villa.get(key)
   # Method: Retrieve a record.
   # `key' specifies a key.  Although it must be an instance of String, binary data is okey.
-  # The return value is an instance of the value of the corresponding record.
+  # The return value is an instance of the value of the corresponding record.  If the silent flag
+  # is true and no record corresponds, nil is returned instead of exception.
   # When the key of duplicated records is specified, the first record of the same key is
   # deleted.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or no record
@@ -225,28 +242,54 @@ class Villa
       key = Marshal.dump(key)
     end
     val = mod_get(@index, key)
-    if(@cmode == CMPOBJ)
+    if(@cmode == CMPOBJ && val)
       val = Marshal.load(val)
     end
     val
   end
   ##
-  # str = villa.fetch(key)
-  # Method: An alias of `get'.
+  # str = villa.fetch(key, defval)
+  # Method: Retrieve a record.
+  # `key' specifies a key.  Although it must be an instance of String, binary data is okey.
+  # `defval' specifies the default value used when no record corresponds.  If it is omitted, nil
+  # is specified.
+  # The return value is an instance of the value of the corresponding record, or the default
+  # value if no record corresponds.
+  # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs.
   #
-  alias fetch get
+  def fetch(key, defval = nil)
+    if @silent
+      if val = mod_get(@index, key)
+        if(@cmode == CMPOBJ)
+          val = Marshal.load(val)
+        end
+        val
+      else
+        defval
+      end
+    else
+      begin
+        val = mod_get(@index, key)
+        if(@cmode == CMPOBJ)
+          val = Marshal.load(val)
+        end
+      rescue ENOITEM
+        defval
+      end
+    end
+  end
   ##
   # str = villa[key]
-  # Method: An alias of `get'.
+  # Method: An alias of `fetch'.
   #
-  alias [] get
+  alias [] fetch
   ##
   # num = villa.vsiz(key)
   # Method: Get the size of the value of a record.
   # `key' specifies a key.  Although it must be an instance of String, binary data is okey.
-  # The return value is the size of the value of the corresponding record.  If no record
-  # corresponds, -1 is returned.  If multiple records correspond, the size of the first is
-  # returned.
+  # The return value is the size of the value of the corresponding record.  If the silent flag
+  # is true and no record corresponds, -1 is returned instead of exception.  If multiple records
+  # correspond, the size of the first is returned.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs.
   #
   def vsiz(key)
@@ -272,7 +315,8 @@ class Villa
   ##
   # bool = villa.curfirst()
   # Method: Move the cursor to the first record.
-  # The return value is always `true'.
+  # The return value is always true.  However, if the silent flag is true and no record
+  # corresponds, false is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or there is
   # no record in the database.
   #
@@ -282,7 +326,8 @@ class Villa
   ##
   # bool = villa.curlast()
   # Method: Move the cursor to the last record.
-  # The return value is always `true'.
+  # The return value is always true.  However, if the silent flag is true and no record
+  # corresponds, false is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or there is
   # no record in the database.
   #
@@ -292,7 +337,8 @@ class Villa
   ##
   # bool = villa.curprev()
   # Method: Move the cursor to the previous record.
-  # The return value is always `true'.
+  # The return value is always true.  However, if the silent flag is true and no record
+  # corresponds, false is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or there is
   # no previous record.
   #
@@ -302,7 +348,8 @@ class Villa
   ##
   # bool = villa.curnext()
   # Method: Move the cursor to the next record.
-  # The return value is always `true'.
+  # The return value is always true.  However, if the silent flag is true and no record
+  # corresponds, false is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or there is
   # no next record.
   #
@@ -319,7 +366,8 @@ class Villa
   # is set to the last record of the same key and that the cursor is set to the previous
   # substitute if completely matching record does not exist.  If it is omitted, `Villa::JFORWARD'
   # is specified.
-  # The return value is always `true'.
+  # The return value is always true.  However, if the silent flag is true and no record
+  # corresponds, false is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or there is
   # no record corresponding the condition.
   #
@@ -332,13 +380,14 @@ class Villa
   ##
   # str = villa.curkey()
   # Method: Get the key of the record where the cursor is.
-  # The return value is the key of the corresponding record.
+  # The return value is the key of the corresponding record.  If the silent flag is true and no
+  # record corresponds, nil is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or no record
   # corresponds to the cursor.
   #
   def curkey()
     key = mod_curkey(@index)
-    if(@cmode == CMPOBJ)
+    if(@cmode == CMPOBJ && key)
       key = Marshal.load(key)
     end
     key
@@ -346,13 +395,14 @@ class Villa
   ##
   # str = villa.curval()
   # Method: Get the value of the record where the cursor is.
-  # The return value is the value of the corresponding record.
+  # The return value is the value of the corresponding record.  If the silent flag is true and no
+  # record corresponds, nil is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or no record
   # corresponds to the cursor.
   #
   def curval()
     val = mod_curval(@index)
-    if(@cmode == CMPOBJ)
+    if(@cmode == CMPOBJ && val)
       val = Marshal.load(val)
     end
     val
@@ -365,7 +415,8 @@ class Villa
   # current record is overwritten, `Villa::CPBEFORE', which means that a new record is inserted
   # before the current record, `Villa::CPAFTER', which means that a new record is inserted after
   # the current record.  If it is omitted, `Villa::CPCURRENT' is specified.
-  # The return value is always `true'.
+  # The return value is always true.  However, if the silent flag is true and no record
+  # corresponds to the cursor, false is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or no record
   # corresponds to the cursor.
   # After insertion, the cursor is moved to the inserted record.
@@ -379,7 +430,8 @@ class Villa
   ##
   # bool = villa.curout();
   # Method: Delete the record where the cursor is.
-  # The return value is always `true'.
+  # The return value is always true.  However, if the silent flag is true and no record
+  # corresponds to the cursor, false is returned instead of exception.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs or no record
   # corresponds to the cursor.
   # After deletion, the cursor is moved to the next record if possible.
@@ -398,7 +450,7 @@ class Villa
   # default value is specified.
   # `ncnum' specifies the max number of caching non-leaf nodes.  If it is not more than 0, the
   # default value is specified.
-  # The return value is always `true'.
+  # The return value is always true.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs.
   # The default setting is equivalent to `vlsettuning(49, 192, 1024, 512)'.  Because tuning
   # parameters are not saved in a database, you should specify them every opening a database.
@@ -409,7 +461,7 @@ class Villa
   ##
   # bool = villa.sync()
   # Method: Synchronize updating contents with the file and the device.
-  # The return value is always `true'.
+  # The return value is always true.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs.
   # This method is useful when another process uses the connected database file.  This method
   # should not be used while the transaction is activated.
@@ -420,7 +472,7 @@ class Villa
   ##
   # bool = villa.optimize()
   # Method: Optimize the database.
-  # The return value is always `true'.
+  # The return value is always true.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs.
   # In an alternating succession of deleting and storing with overwrite or concatenate,
   # dispensable regions accumulate.  This method is useful to do away with them.  This method
@@ -479,7 +531,7 @@ class Villa
   ##
   # bool = villa.tranbegin()
   # Method: Begin the transaction.
-  # The return value is always `true'.
+  # The return value is always true.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs.
   # If a thread is already in the transaction, the other threads block until the prius is out
   # of the transaction.  Only one transaction can be activated with a database handle at the
@@ -499,7 +551,7 @@ class Villa
   ##
   # bool = villa.trancommit()
   # Method: Commit the transaction.
-  # The return value is always `true'.
+  # The return value is always true.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs.
   # Updating a database in the transaction is fixed when it is committed successfully.  Any
   # other thread except for the one which began the transaction should not call this method.
@@ -514,7 +566,7 @@ class Villa
   ##
   # bool = villa.tranabort()
   # Method: Abort the transaction.
-  # The return value is always `true'.
+  # The return value is always true.
   # An exception of `Villa::EANY' or its sub classes is thrown if an error occurs.
   # Updating a database in the transaction is discarded when it is aborted.  The state of the
   # database is rollbacked to before transaction.  Any other thread except for the one which
@@ -558,7 +610,7 @@ class Villa
       curfirst()
       while(true)
         begin
-          key = curkey()
+          break unless key = curkey()
           val = curval()
           yield(key, val)
           curnext()
@@ -584,7 +636,7 @@ class Villa
       curfirst()
       while(true)
         begin
-          key = curkey()
+          break unless key = curkey()
           curnext()
           yield(key)
         rescue ENOITEM
@@ -604,7 +656,7 @@ class Villa
       curfirst()
       while(true)
         begin
-          val = curval()
+          break unless val = curval()
           curnext()
           yield(val)
         rescue ENOITEM
@@ -671,7 +723,8 @@ class Villa
     MyMutex.synchronize() do
       curfirst()
       while(true)
-        if(curval() == val)
+        break unless tmp = curval()
+        if(tmp == val)
           key = curkey()
           break
         end
