@@ -55,9 +55,11 @@
       while(_VL_num > 0){ \
         VL_d = div(_VL_num, 128); \
         _VL_num = VL_d.quot; \
-        ((signed char *)(VL_buf))[(VL_len)] = VL_d.rem; \
-        if(_VL_num > 0) \
-          ((signed char *)(VL_buf))[(VL_len)] = -(((signed char *)(VL_buf))[(VL_len)]) - 1; \
+        if(_VL_num > 0){ \
+          ((signed char *)(VL_buf))[(VL_len)] = -VL_d.rem - 1; \
+        } else { \
+          ((signed char *)(VL_buf))[(VL_len)] = VL_d.rem; \
+        } \
         (VL_len)++; \
       } \
     } \
@@ -188,7 +190,7 @@ VILLA *vlopen(const char *name, int omode, VLCFUNC cmp){
       flags |= VL_FLISZLIB;
     } else if(_qdbm_lzoencode && cmode == VL_OYCOMP){
       flags |= VL_FLISLZO;
-    } else if(_qdbm_lzoencode && cmode == VL_OXCOMP){
+    } else if(_qdbm_bzencode && cmode == VL_OXCOMP){
       flags |= VL_FLISBZIP;
     }
     if(!dpsetflags(depot, flags) || !dpsetalign(depot, VL_PAGEALIGN) ||
@@ -1265,7 +1267,13 @@ int vlrepair(const char *name, VLCFUNC cmp){
   }
   sprintf(path, "%s%s", name, VL_TMPFSUF);
   omode = VL_OWRITER | VL_OCREAT | VL_OTRUNC;
-  if(flags & VL_FLISZLIB) omode |= VL_OZCOMP;
+  if(flags & VL_FLISZLIB){
+    omode |= VL_OZCOMP;
+  } else if(flags & VL_FLISLZO){
+    omode |= VL_OXCOMP;
+  } else if(flags & VL_FLISBZIP){
+    omode |= VL_OYCOMP;
+  }
   if(!(tvilla = vlopen(path, omode, cmp))){
     dpclose(depot);
     return FALSE;
@@ -1279,6 +1287,16 @@ int vlrepair(const char *name, VLCFUNC cmp){
           free(vbuf);
           vbuf = zbuf;
           vsiz = zsiz;
+        } else if(_qdbm_lzodecode && (flags & VL_FLISLZO) &&
+                  (zbuf = _qdbm_lzodecode(vbuf, vsiz, &zsiz)) != NULL){
+          free(vbuf);
+          vbuf = zbuf;
+          vsiz = zsiz;
+        } else if(_qdbm_bzdecode && (flags & VL_FLISBZIP) &&
+                  (zbuf = _qdbm_bzdecode(vbuf, vsiz, &zsiz)) != NULL){
+          free(vbuf);
+          vbuf = zbuf;
+          vsiz = zsiz;
         }
         rp = vbuf;
         size = vsiz;
