@@ -31,7 +31,7 @@
 
 #define \
   dpopen(name, omode, bnum) \
-  cropen(name, omode, ((bnum / vscrdnum) * 2), vscrdnum)
+  cropen(name, omode, ((bnum / vlcrdnum) * 2), vlcrdnum)
 
 #define \
   dpclose(db) \
@@ -168,14 +168,4 @@
 
 
 
-/*************************************************************************************************
- * features for experts
- *************************************************************************************************/
-
-
-/* Number of division of the database. */
-int vscrdnum = 16;
-
-
-
 /* END OF FILE */
