@@ -54,10 +54,10 @@ int printfflush(const char *format, ...);
 void pdperror(const char *name);
 int myrand(void);
 int dowrite(const char *name, int rnum, int ii, int cmode,
-            int lrecmax, int nidxmax, int lcnum, int ncnum);
+            int lrecmax, int nidxmax, int lcnum, int ncnum, int fbp);
 int doread(const char *name, int ii, int vc);
 int dordup(const char *name, int rnum, int pnum, int ii, int cmode, int cc,
-           int lrecmax, int nidxmax, int lcnum, int ncnum);
+           int lrecmax, int nidxmax, int lcnum, int ncnum, int fbp);
 int docombo(const char *name, int cmode);
 int dowicked(const char *name, int rnum, int cb, int cmode);
 
@@ -94,10 +94,10 @@ void usage(void){
   fprintf(stderr, "\n");
   fprintf(stderr, "usage:\n");
   fprintf(stderr, "  %s write [-int] [-cz|-cy|-cx] [-tune lrecmax nidxmax lcnum ncnum]"
-          " name rnum\n", progname);
+          " [-fbp num] name rnum\n", progname);
   fprintf(stderr, "  %s read [-int] [-vc] name\n", progname);
   fprintf(stderr, "  %s rdup [-int] [-cz|-cy|-cx] [-cc] [-tune lrecmax nidxmax lcnum ncnum]"
-          " name rnum pnum\n", progname);
+          " [-fbp num] name rnum pnum\n", progname);
   fprintf(stderr, "  %s combo [-cz|-cy|-cx] name\n", progname);
   fprintf(stderr, "  %s wicked [-c] [-cz|-cy|-cx] name rnum\n", progname);
   fprintf(stderr, "\n");
@@ -108,7 +108,7 @@ void usage(void){
 /* parse arguments of write command */
 int runwrite(int argc, char **argv){
   char *name, *rstr;
-  int i, rnum, ii, cmode, lrecmax, nidxmax, lcnum, ncnum, rv;
+  int i, rnum, ii, cmode, lrecmax, nidxmax, lcnum, ncnum, fbp, rv;
   name = NULL;
   rstr = NULL;
   rnum = 0;
@@ -118,6 +118,7 @@ int runwrite(int argc, char **argv){
   nidxmax = -1;
   lcnum = -1;
   ncnum = -1;
+  fbp = -1;
   for(i = 2; i < argc; i++){
     if(!name && argv[i][0] == '-'){
       if(!strcmp(argv[i], "-int")){
@@ -137,6 +138,9 @@ int runwrite(int argc, char **argv){
         lcnum = atoi(argv[i]);
         if(++i >= argc) usage();
         ncnum = atoi(argv[i]);
+      } else if(!strcmp(argv[i], "-fbp")){
+        if(++i >= argc) usage();
+        fbp = atoi(argv[i]);
       } else {
         usage();
       }
@@ -151,7 +155,7 @@ int runwrite(int argc, char **argv){
   if(!name || !rstr) usage();
   rnum = atoi(rstr);
   if(rnum < 1) usage();
-  rv = dowrite(name, rnum, ii, cmode, lrecmax, nidxmax, lcnum, ncnum);
+  rv = dowrite(name, rnum, ii, cmode, lrecmax, nidxmax, lcnum, ncnum, fbp);
   return rv;
 }
 
@@ -187,7 +191,7 @@ int runread(int argc, char **argv){
 /* parse arguments of rdup command */
 int runrdup(int argc, char **argv){
   char *name, *rstr, *pstr;
-  int i, rnum, pnum, ii, cmode, cc, lrecmax, nidxmax, lcnum, ncnum, rv;
+  int i, rnum, pnum, ii, cmode, cc, lrecmax, nidxmax, lcnum, ncnum, fbp, rv;
   name = NULL;
   rstr = NULL;
   pstr = NULL;
@@ -200,6 +204,7 @@ int runrdup(int argc, char **argv){
   nidxmax = -1;
   lcnum = -1;
   ncnum = -1;
+  fbp = -1;
   for(i = 2; i < argc; i++){
     if(!name && argv[i][0] == '-'){
       if(!strcmp(argv[i], "-int")){
@@ -221,6 +226,9 @@ int runrdup(int argc, char **argv){
         lcnum = atoi(argv[i]);
         if(++i >= argc) usage();
         ncnum = atoi(argv[i]);
+      } else if(!strcmp(argv[i], "-fbp")){
+        if(++i >= argc) usage();
+        fbp = atoi(argv[i]);
       } else {
         usage();
       }
@@ -238,7 +246,7 @@ int runrdup(int argc, char **argv){
   rnum = atoi(rstr);
   pnum = atoi(pstr);
   if(rnum < 1 || pnum < 1) usage();
-  rv = dordup(name, rnum, pnum, ii, cmode, cc, lrecmax, nidxmax, lcnum, ncnum);
+  rv = dordup(name, rnum, pnum, ii, cmode, cc, lrecmax, nidxmax, lcnum, ncnum, fbp);
   return rv;
 }
 
@@ -337,13 +345,13 @@ int myrand(void){
 
 /* perform write command */
 int dowrite(const char *name, int rnum, int ii, int cmode,
-            int lrecmax, int nidxmax, int lcnum, int ncnum){
+            int lrecmax, int nidxmax, int lcnum, int ncnum, int fbp){
   VILLA *villa;
   int i, omode, err, len;
   char buf[RECBUFSIZ];
   printfflush("<Writing Test>\n  name=%s  rnum=%d  int=%d  cmode=%d  "
-              "lrecmax=%d  nidxmax=%d  lcnum=%d  ncnum=%d\n\n",
-              name, rnum, ii, cmode, lrecmax, nidxmax, lcnum, ncnum);
+              "lrecmax=%d  nidxmax=%d  lcnum=%d  ncnum=%d  fbp=%d\n\n",
+              name, rnum, ii, cmode, lrecmax, nidxmax, lcnum, ncnum, fbp);
   /* open a database */
   omode = VL_OWRITER | VL_OCREAT | VL_OTRUNC | cmode;
   if(!(villa = vlopen(name, omode, ii ? VL_CMPINT : VL_CMPLEX))){
@@ -353,6 +361,7 @@ int dowrite(const char *name, int rnum, int ii, int cmode,
   err = FALSE;
   /* set tuning parameters */
   if(lrecmax > 0) vlsettuning(villa, lrecmax, nidxmax, lcnum, ncnum);
+  if(fbp >= 0) vlsetfbpsiz(villa, fbp);
   /* loop for each record */
   for(i = 1; i <= rnum; i++){
     /* store a record */
@@ -460,13 +469,13 @@ int doread(const char *name, int ii, int vc){
 
 /* perform rdup command */
 int dordup(const char *name, int rnum, int pnum, int ii, int cmode, int cc,
-           int lrecmax, int nidxmax, int lcnum, int ncnum){
+           int lrecmax, int nidxmax, int lcnum, int ncnum, int fbp){
   VILLA *villa;
   int i, omode, err, dmode, vi, len;
   char buf[RECBUFSIZ];
   printfflush("<Random Writing Test>\n  name=%s  rnum=%d  int=%d  cmode=%d  "
-              "lrecmax=%d  nidxmax=%d  lcnum=%d  ncnum=%d\n\n",
-              name, rnum, ii, cmode, lrecmax, nidxmax, lcnum, ncnum);
+              "lrecmax=%d  nidxmax=%d  lcnum=%d  ncnum=%d  fbp=%d\n\n",
+              name, rnum, ii, cmode, lrecmax, nidxmax, lcnum, ncnum, fbp);
   omode = VL_OWRITER | VL_OCREAT | VL_OTRUNC | cmode;
   if(!(villa = vlopen(name, omode, ii ? VL_CMPINT : VL_CMPLEX))){
     pdperror(name);
@@ -474,6 +483,7 @@ int dordup(const char *name, int rnum, int pnum, int ii, int cmode, int cc,
   }
   err = FALSE;
   if(lrecmax > 0) vlsettuning(villa, lrecmax, nidxmax, lcnum, ncnum);
+  if(fbp >= 0) vlsetfbpsiz(villa, fbp);
   for(i = 1; i <= rnum; i++){
     dmode = i % 3 == 0 ? VL_DDUPR : VL_DDUP;
     if(cc && myrand() % 2 == 0) dmode = VL_DCAT;
@@ -513,6 +523,7 @@ int dordup(const char *name, int rnum, int pnum, int ii, int cmode, int cc,
 /* perform combo command */
 int docombo(const char *name, int cmode){
   VILLA *villa;
+  VLMULCUR **mulcurs;
   char buf[RECBUFSIZ], *vbuf, *kbuf;
   int i, j, omode, len, vsiz, ksiz, fsiz, lnum, nnum, rnum;
   CBLIST *alist, *dlist;
@@ -1075,7 +1086,6 @@ int docombo(const char *name, int cmode){
     return 1;
   }
   printfflush("ok\n");
-
   printfflush("Deleting records with the cursor ... ");
   if(!vlcurjump(villa, "00000000*", -1, VL_JBACKWARD) ||
      strcmp(vlcurvalcache(villa, NULL), "before") ||
@@ -1142,6 +1152,76 @@ int docombo(const char *name, int cmode){
     return 1;
   }
   printfflush("ok\n");
+  printfflush("Adding 3 * 100 records with VL_DDUP ... ");
+  for(i = 1; i <= 100; i++){
+    len = sprintf(buf, "%08d", i);
+    for(j = 0; j < 3; j++){
+      if(!vlput(villa, buf, len, buf, len, VL_DDUP)){
+        pdperror(name);
+        vlclose(villa);
+        return 1;
+      }
+    }
+  }
+  printfflush("ok\n");
+  printfflush("Closing the database ... ");
+  if(!vlclose(villa)){
+    pdperror(name);
+    return 1;
+  }
+  printfflush("ok\n");
+  printfflush("Opening the database as a reader ... ");
+  if(!(villa = vlopen(name, VL_OREADER, VL_CMPLEX))){
+    pdperror(name);
+    return 1;
+  }
+  printfflush("ok\n");
+  printfflush("Opening multiple cursors ... ");
+  mulcurs = cbmalloc(sizeof(VLMULCUR *) * 8);
+  for(i = 0; i < 8; i++){
+    if(!(mulcurs[i] = vlmulcuropen(villa))){
+      pdperror(name);
+      vlclose(villa);
+      return 1;
+    }
+  }
+  printfflush("ok\n");
+  printfflush("Scanning multiple cursors ... ");
+  for(i = 0; i < 8; i++){
+    if(i % 2 == 0){
+      vlmulcurfirst(mulcurs[i]);
+    } else {
+      vlmulcurlast(mulcurs[i]);
+    }
+  }
+  for(i = 0; i < 300; i++){
+    for(j = 0; j < 8; j++){
+      if(j % 2 == 0){
+        if(!(vbuf = vlmulcurkey(mulcurs[j], &vsiz))){
+          pdperror(name);
+          vlclose(villa);
+          return 1;
+        }
+        free(vbuf);
+        vlmulcurnext(mulcurs[j]);
+      } else {
+        if(!(vbuf = vlmulcurval(mulcurs[j], &vsiz))){
+          pdperror(name);
+          vlclose(villa);
+          return 1;
+        }
+        free(vbuf);
+        vlmulcurprev(mulcurs[j]);
+      }
+    }
+  }
+  printfflush("ok\n");
+  printfflush("Closing multiple cursors ... ");
+  for(i = 0; i < 8; i++){
+    vlmulcurclose(mulcurs[i]);
+  }
+  free(mulcurs);
+  printfflush("ok\n");
   printfflush("Closing the database ... ");
   if(!vlclose(villa)){
     pdperror(name);
